netapp_ontap.models.volume_encryption_support API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_encryption_support`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeEncryptionSupportSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeEncryptionSupport object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `code GET`

    Code corresponding to the status message. Returns a 0 if volume encryption is supported in all nodes of the cluster.

    Example: 346758

  `message GET`

    Reason for not supporting volume encryption.

    Example: No platform support for volume encryption in following nodes - node1, node2.

  `supported GET`

    Set to true when volume encryption support is available on all nodes of the cluster.